#
# spec file for package python-envisage
#
# Copyright (c) 2017 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         X_display         ":98"
%bcond_with     test
Name:           python-envisage
Version:        4.6.0
Release:        1.1
Summary:        Extensible application framework for Python
License:        BSD-3-Clause and Python-2.0 and LGPL-3.0 and CC-BY-SA-1.0 and CC-BY-SA-2.0 and CC-BY-SA-2.5 and CC-BY-SA-3.0 and SUSE-Public-Domain
Group:          Development/Libraries/Python
# Source code is under BSD but images are under different licenses
# and details are inside image_LICENSE.txt
Url:            https://github.com/enthought/envisage
Source:         https://files.pythonhosted.org/packages/source/e/envisage/envisage-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module traits}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module Pygments}
BuildRequires:  %{python_module apptools}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module traitsui}
BuildRequires:  xorg-x11-server
%endif
Requires:       python-traits
BuildArch:      noarch

%python_subpackages

%description
Envisage is a Python-based framework for building extensible applications,
that is, applications whose functionality can be extended by adding "plug-ins".
Envisage provides a standard mechanism for features to be added to an
application, whether by the original developer or by someone else. In fact,
when you build an application using Envisage, the entire application consists
primarily of plug-ins. In this respect, it is similar to the Eclipse and
Netbeans frameworks for Java applications.

Part of the Enthought Tool Suite (ETS).

%prep
%setup -q -n envisage-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%if %{with test}
%check
export DISPLAY=%{X_display}
Xvfb %{X_display} >& Xvfb.log &
trap "kill $! || true" EXIT
sleep 10

%{python_expand mkdir tester_%{$python_bin_suffix}
pushd tester_%{$python_bin_suffix}
export PYTHONPATH=%{buildroot}%{$python_sitelib}
$python -B -m nose.core -v envisage
popd
}
%endif

%files %{python_files}
%defattr(-,root,root,-)
%doc README.rst
%{python_sitelib}/envisage/
%{python_sitelib}/envisage-%{version}-py*.egg-info

%changelog
* Wed Aug 23 2017 toddrme2178@gmail.com
- Implement single-spec version
- Update to version 4.6.0
  * no changelog
* Tue Apr 12 2016 toddrme2178@gmail.com
- Update to Version 4.5.1
  + Enhancements
  * Add tox for testing package install (#67)
  + Fixes
  * Include missing test files in the package data (#67)
  * Include missing test cases for Python 3.4 (#67)
- Update to Version 4.5.0
  + New features
  * IPythonKernelPlugin for Tasks: run an IPython kernel within the
    envisage app and expose it as a service (#54).
  * Envisage now supports Python 3.4 (#61).
  + Enhancements
  * Allow loading plugins from an egg basket even when some eggs are
    invalid (#40, #46).
  * Add a simple ``GUIApplication`` to bootstrap basic plugin-driven
    applications (#34).
  * Split the IPython kernel and IPython menu action into two separate
    plugins for flexibility (#57).
  + Fixes
  * Use new Traits interfaces and adaptation implementation (#37).
  * Envisage now configures the logger with a ``NullHandler`` to avoid
    spurios unconfigured logger warnings (#45).
  * Envisage no longer swallows exceptions in plugin startup (#50).
  * Various fixes to continuous integration configuration (#47, #60).
* Mon Oct 13 2014 toddrme2178@gmail.com
- Update to 4.4.0
  * no changelog
- Update source to pypi url.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sat Apr 20 2013 toddrme2178@gmail.com
- Added a note about being part of the Enthought Tool Suite (ETS).
* Thu Apr 18 2013 toddrme2178@gmail.com
- Update to 4.3.0
  * no changelog
* Tue May 22 2012 toddrme2178@gmail.com
- Initial spec file
